@@ -9,6 +9,22 @@ Mojolicious::Plugin::Swagger2 - Mojolicious plugin for Swagger2
 L<Mojolicious::Plugin::Swagger2> is L<Mojolicious::Plugin> that add routes and
 input/output validation to your L<Mojolicious> application.
 
+Have a look at this L<example blog app|https://github.com/jhthorsen/swagger2/tree/master/t/blog>
+too see a complete working example, with a database backend. Questions and
+comments on how to improve the example are very much welcome.
+
+=over 4
+
+=item * L<Swagger spec|https://github.com/jhthorsen/swagger2/blob/master/t/blog/api.json>
+
+=item * L<Application|https://github.com/jhthorsen/swagger2/blob/master/t/blog/lib/Blog.pm>
+
+=item * L<Controller|https://github.com/jhthorsen/swagger2/blob/master/t/blog/lib/Blog/Controller/Posts.pm>
+
+=item * L<Tests|https://github.com/jhthorsen/swagger2/blob/master/t/authenticate.t>
+
+=back
+
 =head1 SYNOPSIS
 
 =head2 Swagger specification
@@ -337,7 +353,9 @@ sub _validate_input {
 
       if ($in eq 'body' or $in eq 'formData') {
         warn "[Swagger2] Validate $in @{[$c->req->body]}\n" if DEBUG;
-        push @e, map { $_->{path} = "/$name$_->{path}"; $_; } $self->_validator->validate($value, $p->{schema});
+        push @e,
+          map { $_->{path} = $_->{path} eq "/" ? "/$name" : "/$name$_->{path}"; $_; }
+          $self->_validator->validate($value, $p->{schema});
       }
       else {
         warn "[Swagger2] Validate $in $name=$value\n" if DEBUG;
